@@ -95,7 +95,7 @@ class PyLintView(BaseLintView):
     lint_cmd = master_settings.PYLINT_CMD
     lint_is_installed = master_settings.PYLINT_IS_INSTALLED
     title = ''
-    title = 'Pylint'
+    title = 'Py Lint'
 
     def is_valid_file(self, file_path):
         return file_path.endswith('.py')
@@ -105,6 +105,7 @@ class JsLintView(BaseLintView):
     menu_item = 'jslint'
     lint_cmd = master_settings.JSLINT_CMD
     lint_is_installed = master_settings.JSLINT_IS_INSTALLED
+    title = 'JS Lint'
 
     def is_valid_file(self, file_path):
         return file_path.endswith('.js')
