@@ -4,12 +4,11 @@ except ImportError:
     from ordereddict import OrderedDict
 
 from django.conf import settings
-from django.views.generic import ListView
 
-from djangomaster.views import MasterMixin
+from djangomaster.views import MasterView
 
 
-class SettingsListView(MasterMixin, ListView):
+class SettingsListView(MasterView):
     template_name = 'djangomaster/settings.html'
     context_object_name = 'settings_list'
     menu_item = 'settings'
